@@ -478,7 +478,7 @@ void init_cards(const char *cardset, int rx, int ry, const char *cbcolor,
 	if (xpm) {
 	    char s[200];
 	    FILE *fp;
-	    sprintf(s, "%s/Cards.conf", xpm);
+	    sprintf(s, "%s/Cards.conf", xpmdir);
 	    if ((fp = fopen(s, "r"))) {
 		if (fscanf(fp, "%d %d", &CARD_WIDTH, &CARD_HEIGHT) != 2)
 		    CARD_WIDTH = -1;
